@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: BSD-3-Clause
 // Copyright Contributors to the OpenColorIO Project.
 
+#include <cmath>
 #include <cstring>
 #include <iostream>
 #include <set>
@@ -11,6 +12,7 @@
 #include "ParseUtils.h"
 #include "Platform.h"
 #include "utils/StringUtils.h"
+#include "utils/NumberUtils.h"
 
 
 namespace OCIO_NAMESPACE
@@ -255,11 +257,18 @@ Interpolation InterpolationFromString(const char * s)
 
 const char * GpuLanguageToString(GpuLanguage language)
 {
-    if(language == GPU_LANGUAGE_CG) return "cg";
-    else if(language == GPU_LANGUAGE_GLSL_1_2)  return "glsl_1.2";
-    else if(language == GPU_LANGUAGE_GLSL_1_3)  return "glsl_1.3";
-    else if(language == GPU_LANGUAGE_GLSL_4_0)  return "glsl_4.0";
-    else if(language == GPU_LANGUAGE_HLSL_DX11) return "hlsl_dx11";
+    switch(language)
+    {
+        case GPU_LANGUAGE_CG:           return "cg";
+        case GPU_LANGUAGE_GLSL_1_2:     return "glsl_1.2";
+        case GPU_LANGUAGE_GLSL_1_3:     return "glsl_1.3";
+        case GPU_LANGUAGE_GLSL_4_0:     return "glsl_4.0";
+        case GPU_LANGUAGE_GLSL_ES_1_0:  return "glsl_es_1.0";
+        case GPU_LANGUAGE_GLSL_ES_3_0:  return "glsl_es_3.0";
+        case GPU_LANGUAGE_HLSL_SM_5_0:  return "hlsl_sm_5.0";
+        case GPU_LANGUAGE_MSL_2_0:      return "msl_2";
+        case LANGUAGE_OSL_1:            return "osl_1";
+    }
 
     throw Exception("Unsupported GPU shader language.");
 }
@@ -270,10 +279,14 @@ GpuLanguage GpuLanguageFromString(const char * s)
     const std::string str = StringUtils::Lower(p);
 
     if(str == "cg") return GPU_LANGUAGE_CG;
-    else if(str == "glsl_1.2") return GPU_LANGUAGE_GLSL_1_2;
-    else if(str == "glsl_1.3") return GPU_LANGUAGE_GLSL_1_3;
-    else if(str == "glsl_4.0") return GPU_LANGUAGE_GLSL_4_0;
-    else if(str == "hlsl_dx11") return GPU_LANGUAGE_HLSL_DX11;
+    else if(str == "glsl_1.2")    return GPU_LANGUAGE_GLSL_1_2;
+    else if(str == "glsl_1.3")    return GPU_LANGUAGE_GLSL_1_3;
+    else if(str == "glsl_4.0")    return GPU_LANGUAGE_GLSL_4_0;
+    else if(str == "glsl_es_1.0") return GPU_LANGUAGE_GLSL_ES_1_0;
+    else if(str == "glsl_es_3.0") return GPU_LANGUAGE_GLSL_ES_3_0;
+    else if(str == "hlsl_sm_5.0") return GPU_LANGUAGE_HLSL_SM_5_0;
+    else if(str == "osl_1")       return LANGUAGE_OSL_1;
+    else if(str == "msl_2")       return GPU_LANGUAGE_MSL_2_0;
 
     std::ostringstream oss;
     oss << "Unsupported GPU shader language: '" << p << "'.";
@@ -340,23 +353,29 @@ const char * FixedFunctionStyleToString(FixedFunctionStyle style)
 {
     switch(style)
     {
-        case FIXED_FUNCTION_ACES_RED_MOD_03:     return "ACES_RedMod03";
-        case FIXED_FUNCTION_ACES_RED_MOD_10:     return "ACES_RedMod10";
-        case FIXED_FUNCTION_ACES_GLOW_03:        return "ACES_Glow03";
-        case FIXED_FUNCTION_ACES_GLOW_10:        return "ACES_Glow10";
-        case FIXED_FUNCTION_ACES_DARK_TO_DIM_10: return "ACES_DarkToDim10";
-        case FIXED_FUNCTION_REC2100_SURROUND:    return "REC2100_Surround";
-        case FIXED_FUNCTION_RGB_TO_HSV:          return "RGB_TO_HSV";
-        case FIXED_FUNCTION_XYZ_TO_xyY:          return "XYZ_TO_xyY";
-        case FIXED_FUNCTION_XYZ_TO_uvY:          return "XYZ_TO_uvY";
-        case FIXED_FUNCTION_XYZ_TO_LUV:          return "XYZ_TO_LUV";
+        case FIXED_FUNCTION_ACES_RED_MOD_03:            return "ACES_RedMod03";
+        case FIXED_FUNCTION_ACES_RED_MOD_10:            return "ACES_RedMod10";
+        case FIXED_FUNCTION_ACES_GLOW_03:               return "ACES_Glow03";
+        case FIXED_FUNCTION_ACES_GLOW_10:               return "ACES_Glow10";
+        case FIXED_FUNCTION_ACES_DARK_TO_DIM_10:        return "ACES_DarkToDim10";
+        case FIXED_FUNCTION_ACES_GAMUT_COMP_13:         return "ACES_GamutComp13";
+        case FIXED_FUNCTION_ACES_OUTPUT_TRANSFORM_20:   return "ACES2_OutputTransform";
+        case FIXED_FUNCTION_ACES_RGB_TO_JMH_20:         return "ACES2_RGB_TO_JMh";
+        case FIXED_FUNCTION_ACES_TONESCALE_COMPRESS_20: return "ACES2_TonescaleCompress";
+        case FIXED_FUNCTION_ACES_GAMUT_COMPRESS_20:     return "ACES2_GamutCompress";
+        case FIXED_FUNCTION_REC2100_SURROUND:           return "REC2100_Surround";
+        case FIXED_FUNCTION_RGB_TO_HSV:                 return "RGB_TO_HSV";
+        case FIXED_FUNCTION_XYZ_TO_xyY:                 return "XYZ_TO_xyY";
+        case FIXED_FUNCTION_XYZ_TO_uvY:                 return "XYZ_TO_uvY";
+        case FIXED_FUNCTION_XYZ_TO_LUV:                 return "XYZ_TO_LUV";
+        case FIXED_FUNCTION_LIN_TO_PQ:                  return "Lin_TO_PQ";
+        case FIXED_FUNCTION_LIN_TO_GAMMA_LOG:           return "Lin_TO_GammaLog";
+        case FIXED_FUNCTION_LIN_TO_DOUBLE_LOG:          return "Lin_TO_DoubleLog";
         case FIXED_FUNCTION_ACES_GAMUTMAP_02:
         case FIXED_FUNCTION_ACES_GAMUTMAP_07:
-        case FIXED_FUNCTION_ACES_GAMUTMAP_13:
             throw Exception("Unimplemented fixed function types: "
                             "FIXED_FUNCTION_ACES_GAMUTMAP_02, "
-                            "FIXED_FUNCTION_ACES_GAMUTMAP_07, and "
-                            "FIXED_FUNCTION_ACES_GAMUTMAP_13.");
+                            "FIXED_FUNCTION_ACES_GAMUTMAP_07.");
     }
 
     // Default style is meaningless.
@@ -368,16 +387,24 @@ FixedFunctionStyle FixedFunctionStyleFromString(const char * style)
     const char * p = (style ? style : "");
     const std::string str = StringUtils::Lower(p);
 
-    if(str == "aces_redmod03")           return FIXED_FUNCTION_ACES_RED_MOD_03;
-    else if(str == "aces_redmod10")      return FIXED_FUNCTION_ACES_RED_MOD_10;
-    else if(str == "aces_glow03")        return FIXED_FUNCTION_ACES_GLOW_03;
-    else if(str == "aces_glow10")        return FIXED_FUNCTION_ACES_GLOW_10;
-    else if(str == "aces_darktodim10")   return FIXED_FUNCTION_ACES_DARK_TO_DIM_10;
-    else if(str == "rec2100_surround")   return FIXED_FUNCTION_REC2100_SURROUND;
-    else if(str == "rgb_to_hsv")         return FIXED_FUNCTION_RGB_TO_HSV;
-    else if(str == "xyz_to_xyy")         return FIXED_FUNCTION_XYZ_TO_xyY;
-    else if(str == "xyz_to_uvy")         return FIXED_FUNCTION_XYZ_TO_uvY;
-    else if(str == "xyz_to_luv")         return FIXED_FUNCTION_XYZ_TO_LUV;
+    if(str == "aces_redmod03")                return FIXED_FUNCTION_ACES_RED_MOD_03;
+    else if(str == "aces_redmod10")           return FIXED_FUNCTION_ACES_RED_MOD_10;
+    else if(str == "aces_glow03")             return FIXED_FUNCTION_ACES_GLOW_03;
+    else if(str == "aces_glow10")             return FIXED_FUNCTION_ACES_GLOW_10;
+    else if(str == "aces_darktodim10")        return FIXED_FUNCTION_ACES_DARK_TO_DIM_10;
+    else if(str == "aces_gamutcomp13")        return FIXED_FUNCTION_ACES_GAMUT_COMP_13;
+    else if(str == "aces2_outputtransform")   return FIXED_FUNCTION_ACES_OUTPUT_TRANSFORM_20;
+    else if(str == "aces2_rgb_to_jmh")        return FIXED_FUNCTION_ACES_RGB_TO_JMH_20;
+    else if(str == "aces2_tonescalecompress") return FIXED_FUNCTION_ACES_TONESCALE_COMPRESS_20;
+    else if(str == "aces2_gamutcompress")     return FIXED_FUNCTION_ACES_GAMUT_COMPRESS_20;
+    else if(str == "rec2100_surround")        return FIXED_FUNCTION_REC2100_SURROUND;
+    else if(str == "rgb_to_hsv")              return FIXED_FUNCTION_RGB_TO_HSV;
+    else if(str == "xyz_to_xyy")              return FIXED_FUNCTION_XYZ_TO_xyY;
+    else if(str == "xyz_to_uvy")              return FIXED_FUNCTION_XYZ_TO_uvY;
+    else if(str == "xyz_to_luv")              return FIXED_FUNCTION_XYZ_TO_LUV;
+    else if(str == "lin_to_pq")               return FIXED_FUNCTION_LIN_TO_PQ;
+    else if(str == "lin_to_gammalog")         return FIXED_FUNCTION_LIN_TO_GAMMA_LOG;
+    else if(str == "lin_to_doublelog")        return FIXED_FUNCTION_LIN_TO_DOUBLE_LOG;
 
     // Default style is meaningless.
     std::stringstream ss;
@@ -515,6 +542,7 @@ static constexpr int DOUBLE_DECIMALS = 16;
 std::string FloatToString(float value)
 {
     std::ostringstream pretty;
+    pretty.imbue(std::locale::classic());
     pretty.precision(FLOAT_DECIMALS);
     pretty << value;
     return pretty.str();
@@ -525,6 +553,7 @@ std::string FloatVecToString(const float * fval, unsigned int size)
     if(size<=0) return "";
 
     std::ostringstream pretty;
+    pretty.imbue(std::locale::classic());
     pretty.precision(FLOAT_DECIMALS);
     for(unsigned int i=0; i<size; ++i)
     {
@@ -539,9 +568,9 @@ bool StringToFloat(float * fval, const char * str)
 {
     if(!str) return false;
 
-    std::istringstream inputStringstream(str);
-    float x;
-    if(!(inputStringstream >> x))
+    float x = NAN;
+    const auto result = NumberUtils::from_chars(str, str + strlen(str), x);
+    if (result.ec != std::errc())
     {
         return false;
     }
@@ -556,6 +585,7 @@ bool StringToInt(int * ival, const char * str, bool failIfLeftoverChars)
     if(!ival) return false;
 
     std::istringstream i(str);
+    i.imbue(std::locale::classic());
     char c=0;
     if (!(i >> *ival) || (failIfLeftoverChars && i.get(c))) return false;
     return true;
@@ -564,6 +594,7 @@ bool StringToInt(int * ival, const char * str, bool failIfLeftoverChars)
 std::string DoubleToString(double value)
 {
     std::ostringstream pretty;
+    pretty.imbue(std::locale::classic());
     pretty.precision(DOUBLE_DECIMALS);
     pretty << value;
     return pretty.str();
@@ -574,6 +605,7 @@ std::string DoubleVecToString(const double * val, unsigned int size)
     if (size <= 0) return "";
 
     std::ostringstream pretty;
+    pretty.imbue(std::locale::classic());
     pretty.precision(DOUBLE_DECIMALS);
     for (unsigned int i = 0; i<size; ++i)
     {
@@ -590,9 +622,10 @@ bool StringVecToFloatVec(std::vector<float> &floatArray, const StringUtils::Stri
 
     for(unsigned int i=0; i<lineParts.size(); i++)
     {
-        std::istringstream inputStringstream(lineParts[i]);
-        float x;
-        if(!(inputStringstream >> x))
+        float x = NAN;
+        const char *str = lineParts[i].c_str();
+        const auto result = NumberUtils::from_chars(str, str + lineParts[i].size(), x);
+        if (result.ec != std::errc())
         {
             return false;
         }
@@ -639,13 +672,13 @@ bool nextline(std::istream &istream, std::string &line)
         {
             line.resize(line.size() - 1);
         }
-        if(!StringUtils::Trim(line).empty())
+        if(!StringUtils::IsEmptyOrWhiteSpace(line))
         {
             return true;
         }
     }
 
-    line = "";
+    line.clear();
     return false;
 }
 
@@ -721,4 +754,3 @@ int FindInStringVecCaseIgnore(const StringUtils::StringVec & vec, const std::str
     return -1;
 }
 } // namespace OCIO_NAMESPACE
-
