@@ -145,6 +145,11 @@ void CreatePaddedRedChannel(unsigned long width,
 void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
                               ConstLut1DOpDataRcPtr & lutData)
 {
+    if (shaderCreator->getLanguage() == LANGUAGE_OSL_1)
+    {
+        throw Exception("The Lut1DOp is not yet supported by the 'Open Shading language (OSL)' translation");
+    }
+
     const unsigned long defaultMaxWidth = shaderCreator->getTextureMaxWidth();
 
     const unsigned long length      = lutData->getArray().getLength();
@@ -184,6 +189,15 @@ void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
     std::string name(resName.str());
     StringUtils::ReplaceInPlace(name, "__", "_");
 
+    GpuShaderDesc::TextureDimensions dimensions = GpuShaderDesc::TEXTURE_1D;
+    if (height > 1 || lutData->isInputHalfDomain()
+        || shaderCreator->getLanguage() == GPU_LANGUAGE_GLSL_ES_1_0
+        || shaderCreator->getLanguage() == GPU_LANGUAGE_GLSL_ES_3_0
+        || !shaderCreator->getAllowTexture1D())
+    {
+        dimensions = GpuShaderDesc::TEXTURE_2D;
+    }
+
     // (Using CacheID here to potentially allow reuse of existing textures.)
     shaderCreator->addTexture(name.c_str(),
                               GpuShaderText::getSamplerName(name).c_str(),
@@ -191,14 +205,16 @@ void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
                               height,
                               singleChannel ? GpuShaderCreator::TEXTURE_RED_CHANNEL
                                             : GpuShaderCreator::TEXTURE_RGB_CHANNEL,
+                              dimensions,
                               lutData->getConcreteInterpolation(),
                               &values[0]);
 
     // Add the LUT code to the OCIO shader program.
 
-    if (height > 1 || lutData->isInputHalfDomain())
+    if (dimensions == GpuShaderDesc::TEXTURE_2D)
     {
-        // In case the 1D LUT length exceeds the 1D texture maximum length
+        // In case the 1D LUT length exceeds the 1D texture maximum length,
+        // or the language doesn't support 1D textures,
         // a 2D texture is used.
 
         {
@@ -218,7 +234,7 @@ void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
             {
                 static const float NEG_MIN_EXP = 15.0f;
                 static const float EXP_SCALE = 1024.0f;
-                static const float HALF_DENRM_MAX = 6.09755515e-05f;  // e.g. 2^-14 - 2^-24
+                static const float INV_DENRM_STEP = 16777216.0f;  // 1 / 2^-24
 
                 ss.newLine() << "float dep;";
                 ss.newLine() << "float abs_f = abs(f);";
@@ -242,18 +258,29 @@ void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
                 ss.newLine() << "else";
                 ss.newLine() << "{";
                 ss.indent();
-                // Extract bits from denormalized values
-                ss.newLine() << "dep = abs_f * 1023.0 / " << HALF_DENRM_MAX << ";";
+                // Extract bits from denormalized values.
+                ss.newLine() << "dep = abs_f * " << INV_DENRM_STEP << ";";
                 ss.dedent();
                 ss.newLine() << "}";
 
-                // Adjust position for negative values
-                ss.newLine() << "dep += step(f, 0.0) * 32768.0;";
+                // Adjust position for negative values.
+                ss.newLine() << "dep += (f < 0.) ? 32768.0 : 0.0;";
 
-                // At this point 'dep' contains the raw half
+                // At this point 'dep' contains the raw half.
                 // Note: Raw halfs for NaN floats cannot be computed using
                 //       floating-point operations.
-                ss.newLine() << ss.float2Decl("retVal") << ";";
+            }
+            else
+            {
+                // Need clamp() to protect against f outside [0,1] causing a bogus x value.
+                // clamp( f, 0., 1.) * (dim - 1)
+                ss.newLine() << "float dep = clamp(f, 0.0, 1.0) * " << float(length - 1) << ";";
+            }
+
+            ss.newLine() << ss.float2Decl("retVal") << ";";
+
+            if (height > 1)
+            {
                 ss.newLine() << "retVal.y = floor(dep / " << float(width - 1) << ");";       // floor( dep / (width-1) ))
                 ss.newLine() << "retVal.x = dep - retVal.y * " << float(width - 1) << ";";   // dep - retVal.y * (width-1)
 
@@ -262,20 +289,8 @@ void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
             }
             else
             {
-                // Need clamp() to protect against f outside [0,1] causing a bogus x value.
-                // clamp( f, 0., 1.) * (dim - 1)
-                ss.newLine() << "float dep = clamp(f, 0.0, 1.0) * " << float(length - 1) << ";";
-
-                ss.newLine() << ss.float2Decl("retVal") << ";";
-                // float(int( dep / (width-1) ))
-                ss.newLine() << "retVal.y = float(int(dep / " << float(width - 1) << "));";
-                // dep - retVal.y * (width-1)
-                ss.newLine() << "retVal.x = dep - retVal.y * " << float(width - 1) << ";";
-
-                // (retVal.x + 0.5) / width;
-                ss.newLine() << "retVal.x = (retVal.x + 0.5) / " << float(width) << ";";
-                // (retVal.x + 0.5) / height;
-                ss.newLine() << "retVal.y = (retVal.y + 0.5) / " << float(height) << ";";
+                ss.newLine() << "retVal.x = (dep + 0.5) / " << float(width) << ";"; // (dep + 0.5) / width;
+                ss.newLine() << "retVal.y = 0.5;";
             }
 
             ss.newLine() << "return retVal;";
@@ -316,7 +331,7 @@ void GetLut1DGPUShaderProgram(GpuShaderCreatorRcPtr & shaderCreator,
         ss.newLine() << "";
     }
 
-    if (height > 1 || lutData->isInputHalfDomain())
+    if (dimensions == GpuShaderDesc::TEXTURE_2D)
     {
         const std::string str = name + "_computePos(" + shaderCreator->getPixelName();
 
