@@ -6,7 +6,8 @@
 
 #include <OpenColorIO/OpenColorIO.h>
 
-#include "OpenEXR/half.h"
+#include <Imath/half.h>
+
 #include "ops/fixedfunction/FixedFunctionOp.h"
 #include "ops/gradingrgbcurve/GradingRGBCurveOp.h"
 #include "ops/log/LogOp.h"
@@ -496,6 +497,73 @@ void Generate_roll_white_d65_ops(OpRcPtrVec & ops)
 
 }  // namespace ACES_OUTPUT
 
+namespace ACES2_OUTPUT
+{
+    void Generate_output_transform(
+        OpRcPtrVec & ops,
+        float peak_luminance,
+        const Primaries & limiting_pri,
+        const Primaries & encoding_pri,
+        float linear_scale,
+        bool scale_white)
+    {
+        // Clamp to AP1
+        MatrixOpData::MatrixArrayPtr matrixToAP1
+            = build_conversion_matrix(ACES_AP0::primaries, ACES_AP1::primaries, ADAPTATION_NONE);
+        CreateMatrixOp(ops, matrixToAP1, TRANSFORM_DIR_FORWARD);
+
+        const float upperBound = 8.f * (128.f + 768.f * (std::log(peak_luminance / 100.f) / log(10000.f / 100.f)));
+        CreateRangeOp(ops,
+            0., upperBound,
+            0., upperBound,
+            TRANSFORM_DIR_FORWARD);
+
+        CreateMatrixOp(ops, matrixToAP1, TRANSFORM_DIR_INVERSE);
+
+        // Display rendering
+        CreateFixedFunctionOp(ops, FixedFunctionOpData::ACES_OUTPUT_TRANSFORM_20_FWD, {
+            peak_luminance,
+            limiting_pri.m_red.m_xy[0], limiting_pri.m_red.m_xy[1],
+            limiting_pri.m_grn.m_xy[0], limiting_pri.m_grn.m_xy[1],
+            limiting_pri.m_blu.m_xy[0], limiting_pri.m_blu.m_xy[1],
+            limiting_pri.m_wht.m_xy[0], limiting_pri.m_wht.m_xy[1],
+        });
+
+        // Post transform clamp
+        const double normPeakLuminance = peak_luminance / 100.f;
+        CreateRangeOp(ops,
+            0., normPeakLuminance,
+            0., normPeakLuminance,
+            TRANSFORM_DIR_FORWARD);
+
+        // White point simulation
+        if (scale_white)
+        {
+            MatrixOpData::MatrixArrayPtr matrixLimToOut
+                = build_conversion_matrix(limiting_pri, encoding_pri, ADAPTATION_NONE);
+
+            MatrixOpData::Offsets white(1.f, 1.f, 1.f, 0.f);
+            white = matrixLimToOut->inner(white);
+
+            const double scale = 1. / std::max(std::max(white[0], white[1]), white[2]);
+            const double scale4[4] = { scale, scale, scale, 1. };
+            CreateScaleOp(ops, scale4, TRANSFORM_DIR_FORWARD);
+        }
+
+        // Linear scale factor
+        if (linear_scale != 1.f)
+        {
+            const double scale = linear_scale;
+            const double scale4[4] = { scale, scale, scale, 1. };
+            CreateScaleOp(ops, scale4, TRANSFORM_DIR_FORWARD);
+        }
+
+        MatrixOpData::MatrixArrayPtr matrixToXYZ
+            = build_conversion_matrix_to_XYZ_D65(limiting_pri, ADAPTATION_NONE);
+        CreateMatrixOp(ops, matrixToXYZ, TRANSFORM_DIR_FORWARD);
+    }
+
+} // namespace ACES2_OUTPUT
 
 //
 // Create the built-in transforms.
@@ -708,6 +776,24 @@ void RegisterAll(BuiltinTransformRegistryImpl & registry) noexcept
                             "LMT for desaturating blue hues to reduce clipping artifacts",
                             BLUE_LIGHT_FIX_Functor);
     }
+    {
+        auto GAMUT_COMP_13_Functor = [](OpRcPtrVec & ops)
+        {
+            MatrixOpData::MatrixArrayPtr matrix
+                = build_conversion_matrix(ACES_AP0::primaries, ACES_AP1::primaries, ADAPTATION_NONE);
+
+            CreateMatrixOp(ops, matrix, TRANSFORM_DIR_FORWARD);
+
+            CreateFixedFunctionOp(ops, FixedFunctionOpData::ACES_GAMUT_COMP_13_FWD, {
+                1.147, 1.264, 1.312, 0.815, 0.803, 0.880, 1.2});
+
+            CreateMatrixOp(ops, matrix, TRANSFORM_DIR_INVERSE);
+        };
+
+        registry.addBuiltin("ACES-LMT - ACES 1.3 Reference Gamut Compression",
+                            "LMT (applied in ACES2065-1) to compress scene-referred values from common cameras into the AP1 gamut",
+                            GAMUT_COMP_13_Functor);
+    }
 
     //
     // ACES OUTPUT TRANSFORMS
@@ -1028,6 +1114,326 @@ void RegisterAll(BuiltinTransformRegistryImpl & registry) noexcept
                             "Component of ACES Output Transforms for 108 nit HDR D65 cinema",
                             ACES2065_1_to_CIE_XYZ_hdr_cinema_108nits_p3lim_1_1_Functor);
     }
+
+    //
+    // ACES 2 OUTPUT TRANSFORMS
+    //
+
+    struct ACES2OutputTransform
+    {
+        std::string name;
+        std::string desc;
+        float peak_luminance;
+        Primaries limiting_primaries;
+        Primaries encoding_primaries;
+        float linear_scale;
+        bool scale_white;
+    };
+
+    const std::vector<ACES2OutputTransform> aces2_output_transforms {
+        //
+        // D65
+        //
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-REC709_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR Rec709",
+            100.f,
+            REC709::primaries,
+            REC709::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR P3-D65",
+            100.f,
+            P3_D65::primaries,
+            P3_D65::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-108nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 108 nit HDR P3-D65",
+            225.f,  // = 108 * (100/48);
+            P3_D65::primaries,
+            P3_D65::primaries,
+            0.48f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-300nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 300 nit HDR P3-D65",
+            625.f,  // = 300 * (100/48);
+            P3_D65::primaries,
+            P3_D65::primaries,
+            0.48f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-500nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 500 nit HDR P3-D65",
+            500.f,
+            P3_D65::primaries,
+            P3_D65::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 1000 nit HDR P3-D65",
+            1000.f,
+            P3_D65::primaries,
+            P3_D65::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-2000nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 2000 nit HDR P3-D65",
+            2000.f,
+            P3_D65::primaries,
+            P3_D65::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 4000 nit HDR P3-D65",
+            4000.f,
+            P3_D65::primaries,
+            P3_D65::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-500nit-REC2020_2.0",
+            "Component of ACES 2 Output Transforms for 500 nit HDR Rec2020",
+            500.f,
+            REC2020::primaries,
+            REC2020::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-REC2020_2.0",
+            "Component of ACES 2 Output Transforms for 1000 nit HDR Rec2020",
+            1000.f,
+            REC2020::primaries,
+            REC2020::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-2000nit-REC2020_2.0",
+            "Component of ACES 2 Output Transforms for 2000 nit HDR Rec2020",
+            2000.f,
+            REC2020::primaries,
+            REC2020::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-REC2020_2.0",
+            "Component of ACES 2 Output Transforms for 4000 nit HDR Rec2020",
+            4000.f,
+            REC2020::primaries,
+            REC2020::primaries,
+            1.f,
+            false
+        },
+        //
+        // D60
+        //
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-REC709-D60-in-REC709-D65_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR Rec709 simulating D60 white in Rec709",
+            100.f,
+            REC709_D60::primaries,
+            REC709::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-REC709-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR Rec709 simulating D60 white in P3-D65",
+            100.f,
+            REC709_D60::primaries,
+            P3_D65::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-REC709-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR Rec709 simulating D60 white in Rec2020",
+            100.f,
+            REC709_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-P3-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR P3-D60 simulating D60 white in P3-D65",
+            100.f,
+            P3_D60::primaries,
+            P3_D65::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-P3-D60-in-XYZ-E_2.0",
+            "Component of ACES 2 Output Transforms for 100 nit SDR P3-D60 simulating D60 white in XYZ-E",
+            100.f,
+            P3_D60::primaries,
+            CIE_XYZ_ILLUM_E::primaries,
+            1.f,
+            false
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-108nit-P3-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 108 nit HDR P3-D60 simulating D60 white in P3-D65",
+            225.f,  // = 108 * (100/48);
+            P3_D60::primaries,
+            P3_D65::primaries,
+            0.48f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-300nit-P3-D60-in-XYZ-E_2.0",
+            "Component of ACES 2 Output Transforms for 300 nit HDR P3-D60 simulating D60 white in XYZ-E",
+            625.f,  // = 300 * (100/48);
+            P3_D60::primaries,
+            CIE_XYZ_ILLUM_E::primaries,
+            0.48f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-500nit-P3-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 500 nit HDR P3-D60 simulating D60 white in P3-D65",
+            500.f,
+            P3_D60::primaries,
+            P3_D65::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-P3-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 1000 nit HDR P3-D60 simulating D60 white in P3-D65",
+            1000.f,
+            P3_D60::primaries,
+            P3_D65::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-2000nit-P3-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 2000 nit HDR P3-D60 simulating D60 white in P3-D65",
+            2000.f,
+            P3_D60::primaries,
+            P3_D65::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D60-in-P3-D65_2.0",
+            "Component of ACES 2 Output Transforms for 4000 nit HDR P3-D60 simulating D60 white in P3-D65",
+            4000.f,
+            P3_D60::primaries,
+            P3_D65::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-500nit-P3-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 500 nit HDR P3-D60 simulating D60 white in Rec2020",
+            500.f,
+            P3_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-P3-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 1000 nit HDR P3-D60 simulating D60 white in Rec2020",
+            1000.f,
+            P3_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-2000nit-P3-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 2000 nit HDR P3-D60 simulating D60 white in Rec2020",
+            2000.f,
+            P3_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 4000 nit HDR P3-D60 simulating D60 white in Rec2020",
+            4000.f,
+            P3_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-500nit-REC2020-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 500 nit HDR Rec2020 simulating D60 white in Rec2020",
+            500.f,
+            REC2020_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-REC2020-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 1000 nit HDR Rec2020 simulating D60 white in Rec2020",
+            1000.f,
+            REC2020_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-2000nit-REC2020-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 2000 nit HDR Rec2020 simulating D60 white in Rec2020",
+            2000.f,
+            REC2020_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        },
+        {
+            "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-REC2020-D60-in-REC2020-D65_2.0",
+            "Component of ACES 2 Output Transforms for 4000 nit HDR Rec2020 simulating D60 white in Rec2020",
+            4000.f,
+            REC2020_D60::primaries,
+            REC2020::primaries,
+            1.f,
+            true
+        }
+    };
+
+    for (const auto& tr : aces2_output_transforms)
+    {
+        auto functor = [tr](OpRcPtrVec & ops)
+        {
+            ACES2_OUTPUT::Generate_output_transform(
+                ops,
+                tr.peak_luminance,
+                tr.limiting_primaries,
+                tr.encoding_primaries,
+                tr.linear_scale,
+                tr.scale_white
+            );
+        };
+
+        registry.addBuiltin(tr.name.c_str(), tr.desc.c_str(), functor);
+    }
 }
 
 } // namespace ACES
