@@ -33,17 +33,22 @@ void ApplyFixedFunction(float * input_32f,
         // Using rel error with a large minExpected value of 1 will transition
         // from absolute error for expected values < 1 and
         // relative error for values > 1.
+        float computedError = 0.0f;
         const bool equalRel = OCIO::EqualWithSafeRelError(input_32f[idx],
                                                           expected_32f[idx],
                                                           errorThreshold,
-                                                          1.0f);
+                                                          1.0f,
+                                                          &computedError);
         if (!equalRel)
         {
             std::ostringstream errorMsg;
             errorMsg.precision(14);
             errorMsg << "Index: " << idx;
             errorMsg << " - Values: " << input_32f[idx] << " expected: " << expected_32f[idx];
-            errorMsg << " - Threshold: " << errorThreshold;
+            errorMsg << " - Error: " << computedError << " ("
+                     << std::setprecision(3) << computedError / errorThreshold;
+            errorMsg << "x of Threshold: "
+                     << std::setprecision(6) << errorThreshold << ")";
             OCIO_CHECK_ASSERT_MESSAGE_FROM(0, errorMsg.str(), lineNo);
         }
     }
@@ -462,45 +467,45 @@ OCIO_ADD_TEST(FixedFunctionOpCPU, aces_output_transform_20)
 
     const float expected_32f[num_samples*4] = {
         // ACEScg primaries and secondaries scaled by 4
-        4.965774059f, -0.032864563f, 0.041625995f, 1.0f,
-        3.969441891f, 3.825784922f, -0.056133576f, 1.0f,
-        -0.075329021f, 3.688980103f, 0.270296901f, 1.0f,
-        -0.095423937f, 3.650517225f, 3.459972620f, 1.0f,
-        -0.028930068f, 0.196428135f, 2.796343565f, 1.0f,
-        4.900805950f, -0.064376131f, 3.838256121f, 1.0f,
+        4.966013432f, -0.033002287f, 0.041583523f, 1.0f,
+        3.969460726f, 3.825797558f, -0.056160748f, 1.0f,
+        -0.075460039f, 3.689072609f, 0.270235062f, 1.0f,
+        -0.095436633f, 3.650521517f, 3.459975719f, 1.0f,
+        -0.028881177f, 0.196473420f, 2.796123743f, 1.0f,
+        4.900828362f, -0.064385533f, 3.838270903f, 1.0f,
         // OCIO test values
-        0.096890204f, -0.001135312f, 0.018971510f, 0.5f,
-        0.809614301f, 0.479856580f, 0.814239502f, 1.0f,
-        0.107420206f, 0.920529068f, 0.726378500f, 0.0f,
+        0.096890487f, -0.001135427f, 0.018971475f, 0.5f,
+        0.809613585f, 0.479857147f, 0.814239979f, 1.0f,
+        0.107417941f, 0.920530438f, 0.726379037f, 0.0f,
         // ColorChecker24 (SMPTE 2065-1 2021)
-        0.115475260f, 0.050812904f, 0.030212952f, 1.0f,
-        0.484879673f, 0.301042974f, 0.226768956f, 1.0f,
-        0.098463766f, 0.160814658f, 0.277010560f, 1.0f,
-        0.071130365f, 0.107334383f, 0.035097566f, 1.0f,
-        0.207111493f, 0.198474824f, 0.375326216f, 1.0f,
-        0.195447892f, 0.481111974f, 0.393299013f, 1.0f,
-        0.571913838f, 0.196872935f, 0.041634772f, 1.0f,
-        0.045791931f, 0.069875360f, 0.291233480f, 1.0f,
-        0.424848706f, 0.083199009f, 0.102153838f, 1.0f,
-        0.059589427f, 0.022219172f, 0.091246888f, 1.0f,
-        0.360365510f, 0.478741467f, 0.086726837f, 1.0f,
-        0.695662081f, 0.371994525f, 0.068298168f, 1.0f,
-        0.011806309f, 0.021665439f, 0.199594811f, 1.0f,
-        0.076526314f, 0.256237417f, 0.060564656f, 1.0f,
-        0.300064564f, 0.023416257f, 0.030360471f, 1.0f,
-        0.805484772f, 0.596903503f, 0.082996152f, 1.0f,
-        0.388385952f, 0.079899102f, 0.245819211f, 1.0f,
-        0.010952532f, 0.196105912f, 0.307181358f, 1.0f,
-        0.921019495f, 0.921707213f, 0.912856042f, 1.0f,
-        0.590192318f, 0.588423848f, 0.587825358f, 1.0f,
-        0.337743521f, 0.337685764f, 0.338155121f, 1.0f,
-        0.169265985f, 0.169178501f, 0.169557109f, 1.0f,
-        0.058346048f, 0.059387825f, 0.060296260f, 1.0f,
-        0.012581184f, 0.012947139f, 0.013654195f, 1.0f,
+        0.115475342f, 0.050812997f, 0.030212998f, 1.0f,
+        0.484880149f, 0.301042914f, 0.226769030f, 1.0f,
+        0.098463453f, 0.160814837f, 0.277010798f, 1.0f,
+        0.071130276f, 0.107334509f, 0.035097614f, 1.0f,
+        0.207111374f, 0.198474824f, 0.375326097f, 1.0f,
+        0.195447117f, 0.481112540f, 0.393299103f, 1.0f,
+        0.571913302f, 0.196873263f, 0.041634843f, 1.0f,
+        0.045791976f, 0.069875412f, 0.291233569f, 1.0f,
+        0.424848884f, 0.083199054f, 0.102153927f, 1.0f,
+        0.059589352f, 0.022219239f, 0.091246955f, 1.0f,
+        0.360364884f, 0.478741497f, 0.086726815f, 1.0f,
+        0.695661962f, 0.371994466f, 0.068298057f, 1.0f,
+        0.011806240f, 0.021665439f, 0.199594870f, 1.0f,
+        0.076526135f, 0.256237596f, 0.060564563f, 1.0f,
+        0.300064713f, 0.023416281f, 0.030360531f, 1.0f,
+        0.805483222f, 0.596904039f, 0.082996234f, 1.0f,
+        0.388385385f, 0.079899333f, 0.245818958f, 1.0f,
+        0.010951802f, 0.196106046f, 0.307181537f, 1.0f,
+        0.921020269f, 0.921707630f, 0.912857533f, 1.0f,
+        0.590191603f, 0.588424563f, 0.587825298f, 1.0f,
+        0.337743223f, 0.337686002f, 0.338155240f, 1.0f,
+        0.169266403f, 0.169178575f, 0.169557154f, 1.0f,
+        0.058346011f, 0.059387885f, 0.060296256f, 1.0f,
+        0.012581199f, 0.012947144f, 0.013654212f, 1.0f,
         // Spectrally non-selective 18 % reflecting diffuser
-        0.145115465f, 0.145115525f, 0.145115510f, 1.0f,
+        0.145115077f, 0.145115703f, 0.145115480f, 1.0f,
         // Perfect reflecting diffuser
-        1.041565657f, 1.041566014f, 1.041565657f, 1.0f,
+        1.041565537f, 1.041566610f, 1.041566253f, 1.0f,
     };
 
     OCIO::FixedFunctionOpData::Params params = {
@@ -518,6 +523,17 @@ OCIO_ADD_TEST(FixedFunctionOpCPU, aces_output_transform_20)
                        1e-5f,
                        __LINE__);
 
+#if DUMP_RESULT
+    std::cout << "aces_output_transform_20 results: \n" << std::setprecision(9) << std::fixed;
+    for (unsigned i = 0; i < num_samples; ++i) 
+    {
+        std::cout   << input2_32f[i * 4 + 0] << "f, "
+                    << input2_32f[i * 4 + 1] << "f, " 
+                    << input2_32f[i * 4 + 2] << "f, "
+                    << input2_32f[i * 4 + 3] << "f,\n";
+    }
+#endif
+
     OCIO::ConstFixedFunctionOpDataRcPtr funcData2
         = std::make_shared<OCIO::FixedFunctionOpData>(OCIO::FixedFunctionOpData::ACES_OUTPUT_TRANSFORM_20_INV,
                                                       params);
@@ -528,6 +544,13 @@ OCIO_ADD_TEST(FixedFunctionOpCPU, aces_output_transform_20)
                        __LINE__);
 }
 
+// NB: The ACES 2 FixedFunction takes linear ACES2065-1 values and produces linear RGB values
+// in the encoding gamut. The relatively large tolerance on the following round-trip tests doesn't
+// fully test accuracy of saturated values. See additional tests in BuiltinTransform_tests.cpp
+// that do a similar round-trip but using gamma-corrected code values and therefore does
+// a more thorough test of colors where one or more channels is near zero, which is an area
+// that is more challenging for the algorithm to invert.
+
 OCIO_ADD_TEST(FixedFunctionOpCPU, aces_ot_20_rec709_100n_rt)
 {
     const int lut_size = 8;
@@ -778,35 +801,35 @@ OCIO_ADD_TEST(FixedFunctionOpCPU, aces_tonescale_compress_20)
 
     const float expected_32f[num_samples*4] = {
         // ACEScg primaries and secondaries scaled by 4
-        110.702453613f, 211.251770020f, 25.025110245f, 1.0f,
+        110.702453613f, 211.251770020f, 25.025110245f,  1.0f,
         168.016815186f, 129.796249390f, 106.183448792f, 1.0f,
-        140.814849854f, 193.459213257f, 147.056488037f, 1.0f,
-        156.429519653f, 110.938514709f, 192.204727173f, 1.0f,
-        80.456542969f, 98.490524292f, 268.442108154f, 1.0f,
-        135.172195435f, 175.559280396f, 341.715240479f, 1.0f,
+        140.814849854f, 193.459197998f, 147.056488037f, 1.0f,
+        156.429504395f, 110.938423157f, 192.204727173f, 1.0f,
+        80.456558228f, 98.490531921f, 268.442108154f,   1.0f,
+        135.172225952f, 175.559326172f, 341.715240479f, 1.0f,
         // OCIO test values
-        18.187314987f, 33.819175720f, 4.173158169f, 0.5f,
-        80.413116455f, 21.309329987f, 332.159759521f, 1.0f,
-        83.447891235f, 37.852291107f, 182.925750732f, 0.0f,
+        18.187316895f, 33.819190979f, 4.173158169f,   0.5f,
+        80.413101196f, 21.309329987f, 332.159759521f, 1.0f,
+        83.447883606f, 37.852523804f, 182.925750732f, 0.0f,
         // ColorChecker24 (SMPTE 2065-1 2021)
-        27.411964417f, 13.382769585f, 38.146659851f, 1.0f,
-        59.987670898f, 14.391894341f, 39.841842651f, 1.0f,
+        27.411968231f, 13.382784843f, 38.146659851f,  1.0f,
+        59.987659454f, 14.391894341f, 39.841842651f,  1.0f,
         43.298923492f, 12.199877739f, 249.107116699f, 1.0f,
-        31.489658356f, 14.075142860f, 128.878036499f, 1.0f,
-        50.749198914f, 12.731814384f, 285.658966064f, 1.0f,
-        64.728637695f, 18.593795776f, 179.324264526f, 1.0f,
-        53.399448395f, 37.394428253f, 50.924011230f, 1.0f,
+        31.489654541f, 14.075141907f, 128.878036499f, 1.0f,
+        50.749198914f, 12.731806755f, 285.658966064f, 1.0f,
+        64.728637695f, 18.593791962f, 179.324264526f, 1.0f,
+        53.399444580f, 37.394416809f, 50.924011230f,  1.0f,
         34.719596863f, 21.616765976f, 271.008331299f, 1.0f,
-        43.910713196f, 36.788166046f, 13.975610733f, 1.0f,
-        23.196525574f, 15.118354797f, 317.544281006f, 1.0f,
-        63.348674774f, 33.283493042f, 119.145133972f, 1.0f,
-        64.908889771f, 35.371044159f, 70.842193604f, 1.0f,
-        24.876911163f, 23.143159866f, 273.228973389f, 1.0f,
+        43.910709381f, 36.788166046f, 13.975610733f,  1.0f,
+        23.196529388f, 15.118354797f, 317.544281006f, 1.0f,
+        63.348682404f, 33.283519745f, 119.145133972f, 1.0f,
+        64.908874512f, 35.371063232f, 70.842193604f,  1.0f,
+        24.876913071f, 23.143159866f, 273.228973389f, 1.0f,
         44.203376770f, 28.918329239f, 144.154159546f, 1.0f,
-        32.824356079f, 43.447875977f, 17.892261505f, 1.0f,
-        75.830871582f, 39.872474670f, 90.752044678f, 1.0f,
-        45.823116302f, 34.652069092f, 348.832092285f, 1.0f,
-        43.597240448f, 23.079078674f, 218.454376221f, 1.0f,
+        32.824359894f, 43.447853088f, 17.892261505f,  1.0f,
+        75.830871582f, 39.872489929f, 90.752044678f,  1.0f,
+        45.823120117f, 34.652057648f, 348.832092285f, 1.0f,
+        43.597236633f, 23.079071045f, 218.454376221f, 1.0f,
     };
 
     OCIO::FixedFunctionOpData::Params params = {1000.f};
@@ -871,35 +894,35 @@ OCIO_ADD_TEST(FixedFunctionOpCPU, aces_gamut_map_20)
 
     const float expected_32f[num_samples*4] = {
         // ACEScg primaries and secondaries scaled by 4
-        107.831291199f, 174.252944946f, 25.025119781f, 1.0f,
-        168.028198242f, 118.224960327f, 106.183464050f, 1.0f,
-        140.030105591f, 127.177192688f, 147.056488037f, 1.0f,
-        156.512435913f, 73.218856812f, 192.204727173f, 1.0f,
-        79.378631592f, 72.613555908f, 268.442108154f, 1.0f,
-        133.827835083f, 149.929809570f, 341.715240479f, 1.0f,
+        107.829742432f, 174.270156860f, 25.025110245f,  1.0f,
+        168.028274536f, 118.227561951f, 106.183448792f, 1.0f,
+        140.030166626f, 127.184478760f, 147.056488037f, 1.0f,
+        156.512435913f, 73.219184875f,  192.204727173f, 1.0f,
+        79.378555298f,  72.608604431f,  268.442108154f, 1.0f,
+        133.827941895f, 149.930618286f, 341.715240479f, 1.0f,
         // OCIO test values
-        18.194000244f, 33.312938690f, 4.173166752f, 0.5f,
-        80.413116455f, 21.309329987f, 332.159759521f, 1.0f,
-        83.467437744f, 37.305160522f, 182.925750732f, 0.0f,
+        18.193992615f,  33.313068390f,  4.173158169f,   0.5f,
+        80.413116455f,  21.309329987f,  332.159759521f, 1.0f,
+        83.467445374f,  37.305030823f,  182.925750732f, 0.0f,
         // ColorChecker24 (SMPTE 2065-1 2021)
-        27.411962509f, 13.382793427f, 38.146591187f, 1.0f,
-        59.987670898f, 14.391893387f, 39.841842651f, 1.0f,
-        43.298923492f, 12.199877739f, 249.107116699f, 1.0f,
-        31.489658356f, 14.075142860f, 128.878036499f, 1.0f,
-        50.749198914f, 12.731814384f, 285.658966064f, 1.0f,
-        64.728637695f, 18.593795776f, 179.324264526f, 1.0f,
-        53.399448395f, 37.394428253f, 50.924011230f, 1.0f,
-        34.719596863f, 21.616765976f, 271.008331299f, 1.0f,
-        43.910709381f, 36.788166046f, 13.975610733f, 1.0f,
-        23.196525574f, 15.118361473f, 317.544250488f, 1.0f,
-        63.348674774f, 33.283493042f, 119.145133972f, 1.0f,
-        64.908889771f, 35.371044159f, 70.842193604f, 1.0f,
-        24.876916885f, 23.143167496f, 273.229034424f, 1.0f,
-        44.203376770f, 28.918329239f, 144.154159546f, 1.0f,
-        32.824352264f, 43.447864532f, 17.892255783f, 1.0f,
-        75.830871582f, 39.872474670f, 90.752044678f, 1.0f,
-        45.823104858f, 34.652038574f, 348.832092285f, 1.0f,
-        43.635551453f, 21.629474640f, 218.454376221f, 1.0f,
+        27.411962509f,  13.382769585f,  38.146659851f,  1.0f,
+        59.987674713f,  14.391894341f,  39.841842651f,  1.0f,
+        43.298919678f,  12.199877739f,  249.107116699f, 1.0f,
+        31.489658356f,  14.075142860f,  128.878036499f, 1.0f,
+        50.749198914f,  12.731814384f,  285.658966064f, 1.0f,
+        64.728637695f,  18.593795776f,  179.324264526f, 1.0f,
+        53.399448395f,  37.394428253f,  50.924011230f,  1.0f,
+        34.719596863f,  21.616765976f,  271.008331299f, 1.0f,
+        43.910713196f,  36.788166046f,  13.975610733f,  1.0f,
+        23.196525574f,  15.118354797f,  317.544281006f, 1.0f,
+        63.348674774f,  33.283493042f,  119.145133972f, 1.0f,
+        64.908882141f,  35.371044159f,  70.842193604f,  1.0f,
+        24.876911163f,  23.143159866f,  273.228973389f, 1.0f,
+        44.203376770f,  28.918329239f,  144.154159546f, 1.0f,
+        32.824356079f,  43.447875977f,  17.892261505f,  1.0f,
+        75.830871582f,  39.872474670f,  90.752044678f,  1.0f,
+        45.823112488f,  34.652069092f,  348.832092285f, 1.0f,
+        43.635547638f,  21.629518509f,  218.454376221f, 1.0f,
     };
 
     OCIO::FixedFunctionOpData::Params params = {
