@@ -1109,6 +1109,16 @@ colorspaces:
     dt->setDisplay("display");
     dt->setView("view");
 
+    // This results in the following conversion:
+    //   displayCSIn to scene_ref                                 offset= -0.15 0.15 0.15 0.05
+    //   scene_ref to display_ref                                 offset= -0.2 -0.2 -0.4 -0
+    //   display_ref to displayCSProcess (look process_space)     offset= -0.1 -0.1 -0.1 -0
+    //   apply look                                               offset=  0.1 0.2 0.3 0
+    //   displayCSProcess to display_ref                          offset=  0.1 0.1 0.1 0
+    //   apply display_vt                                         offset= -0.3 -0.1 -0.1 -0
+    //   display_ref to displayCSOut                              offset= -0.25 -0.15 -0.35 -0
+    // Total transformation:                                      offset= -0.8 -0.1 -0.4 0.05
+
     OCIO::ConstProcessorRcPtr proc;
     OCIO_CHECK_NO_THROW(proc = config->getProcessor(dt));
     // Remove the no-ops, since they are useless here.
@@ -1219,6 +1229,126 @@ colorspaces:
     groupProc = groupProc->getOptimizedProcessor(OCIO::BIT_DEPTH_F32, OCIO::BIT_DEPTH_F32,
                                                  OCIO::OPTIMIZATION_DEFAULT);
     OCIO_CHECK_ASSERT(groupProc->isNoOp());
+
+    //
+    // Check that the correct error message is thrown in various scenarios.
+    //
+
+    dt->setSrc("displayCSIn");
+    dt->setDisplay("display");
+    dt->setView("view");
+
+    // Empty arguments get handled in DisplayViewTransform::validate.
+
+    // Display name is empty.
+    dt->setDisplay("");
+    OCIO_CHECK_THROW_WHAT(config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform: empty display name."
+    );
+    dt->setDisplay("display");
+
+    // View name is empty.
+    dt->setView("");
+    OCIO_CHECK_THROW_WHAT(config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform: empty view name."
+    );
+    dt->setView("view");
+
+    // Source CS is empty.
+    dt->setSrc("");
+    OCIO_CHECK_THROW_WHAT(config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform: empty source color space name."
+    );
+
+    // More detailed error handling is in DisplayViewTransform::BuildDisplayOps.
+
+    // Source CS doesn't exist in the config.
+    dt->setSrc("missing cs");
+    OCIO_CHECK_THROW_WHAT(config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform error. Cannot find source color space named 'missing cs'."
+    );
+    dt->setSrc("displayCSIn");
+
+    // Display doesn't exist in the config.
+    dt->setDisplay("missing display");
+    OCIO_CHECK_THROW_WHAT(config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform error. Display 'missing display' not found."
+    );
+    dt->setDisplay("display");
+
+    OCIO::ConfigRcPtr e_config = config->createEditableCopy();
+
+    // View references a view transform that doesn't exist in the config.
+    OCIO_CHECK_NO_THROW(e_config->addDisplayView("display", "bad_view", "missing vt",
+                                                 "displayCSOut", "", "", ""));
+    dt->setView("bad_view");
+    OCIO_CHECK_THROW_WHAT(e_config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform error. The view transform 'missing vt' is neither "
+                          "a view transform nor a named transform."
+    );
+
+    // View doesn't exist in the config.
+    dt->setView("missing view");
+    OCIO_CHECK_THROW_WHAT(config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform error. The display 'display' does not have "
+                          "view 'missing view'."
+    );
+
+    // View references a "display_colorspace" that doesn't exist in the config.
+    OCIO_CHECK_NO_THROW(e_config->addDisplayView("display", "bad_view", "display_vt",
+                                                 "missing cs", "", "", ""));
+    dt->setView("bad_view");
+    OCIO_CHECK_THROW_WHAT(e_config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform error. The view 'bad_view' refers to a display "
+                          "color space 'missing cs' that can't be found."
+    );
+    // As with most of these, validation also fails.
+    OCIO_CHECK_THROW_WHAT(e_config->validate(),
+                          OCIO::Exception,
+                          "Config failed display view validation. Display 'display' has a view 'bad_view' that "
+                          "refers to a color space or a named transform, 'missing cs', which is not defined."
+    );
+
+    // View references a "colorspace" that doesn't exist in the config.
+    OCIO_CHECK_NO_THROW(e_config->addDisplayView("display", "bad_view", "missing cs", ""));
+    dt->setView("bad_view");
+    OCIO_CHECK_THROW_WHAT(e_config->getProcessor(dt),
+                          OCIO::Exception,
+                          "DisplayViewTransform error. Cannot find color space or named transform "
+                          "with name 'missing cs'."
+    );
+
+    // Check a few more scenarios.
+
+    // Missing look.
+    OCIO_CHECK_NO_THROW(e_config->addDisplayView("display", "bad_view", "display_vt",
+                                                 "displayCSOut", "missing look", "", ""));
+    dt->setView("bad_view");
+    OCIO_CHECK_THROW_WHAT(e_config->getProcessor(dt),
+                          OCIO::Exception,
+                          "RunLookTokens error. The specified look, 'missing look', cannot be "
+                          "found.  (looks: look)."
+    );
+    dt->setView("view");
+
+    // Missing viewing rule does not currently throw when getting a processor.
+    OCIO_CHECK_NO_THROW(e_config->addDisplayView("display", "bad_view", "display_vt",
+                                                 "displayCSOut", "", "missing rule", "desc: foo"));
+    OCIO_CHECK_NO_THROW(e_config->getProcessor(dt));
+    // But validation fails.
+    OCIO_CHECK_THROW_WHAT(e_config->validate(),
+                          OCIO::Exception,
+                          "Config failed display view validation. Display 'display' has a view 'bad_view' refers "
+                          "to a viewing rule, 'missing rule', which is not defined."
+    );
 }
 
 OCIO_ADD_TEST(DisplayViewTransform, context_variables)
