@@ -10,7 +10,7 @@
 namespace OCIO = OCIO_NAMESPACE;
 
 
-#ifdef USE_SSE
+#if OCIO_USE_SSE2
 const float g_epsilon = 1e-4f;
 const float g_epsilon_inverse = 1e-3f;
 #else
@@ -319,9 +319,9 @@ OCIO_ADD_GPU_TEST(LogCameraTransform, camera_lin2log)
 
     test.setErrorThreshold(g_epsilon);
 
+    test.setTestInfinity(false);
 #ifdef __APPLE__
     test.setTestNaN(false);
-    test.setTestInfinity(false);
 #endif
 }
 
@@ -346,8 +346,8 @@ OCIO_ADD_GPU_TEST(LogCameraTransform, camera_log2lin)
 
     test.setErrorThreshold(g_epsilon_inverse);
 
+    test.setTestInfinity(false);
 #ifdef __APPLE__
     test.setTestNaN(false);
-    test.setTestInfinity(false);
 #endif
 }
