@@ -10,9 +10,7 @@ from UnitTestUtils import SAMPLE_CONFIG
 
 def test_percent_1000(a, b):
     # Helper function to test sliders.
-    if (a == (int)(100000 * b)):
-        return True
-    return False
+    return abs(a - int(100000 * b)) <= 1
 
 class MixingHelpersTest(unittest.TestCase):
 
@@ -28,7 +26,7 @@ class MixingHelpersTest(unittest.TestCase):
         """
         mix = OCIO.MixingColorSpaceManager(self.cfg)
 
-        self.assertEqual(mix.getSelectedMixingEncodingIdx(), 0);
+        self.assertEqual(mix.getSelectedMixingEncodingIdx(), 0)
         encodings = mix.getMixingEncodings()
         self.assertEqual(len(encodings), 2)
         self.assertEqual(encodings[0], 'RGB')
@@ -52,7 +50,7 @@ class MixingHelpersTest(unittest.TestCase):
 
         # Print the MixingColorSpaceManager.
         self.assertEqual(str(mix),
-            ('config: $0f5cce49d82e023765b1d657191c3417:$4dd1c89df8002b409e089089ce8f24e7, '
+            ('config: 667ca4dc5b3779e570229fb7fd9cffe1:6001c324468d497f99aa06d3014798d8, '
             'slider: [minEdge: 0, maxEdge: 0.833864], mixingSpaces: [Rendering Space, '
             'Display Space], selectedMixingSpaceIdx: 0, selectedMixingEncodingIdx: 0'))
 
@@ -64,7 +62,7 @@ class MixingHelpersTest(unittest.TestCase):
         """
         mix = OCIO.MixingColorSpaceManager(self.cfg)
 
-        self.assertEqual(mix.getSelectedMixingSpaceIdx(), 0);
+        self.assertEqual(mix.getSelectedMixingSpaceIdx(), 0)
         mixSpaces = mix.getMixingSpaces()
         self.assertEqual(len(mixSpaces), 2)
         self.assertEqual(mixSpaces[0], 'Rendering Space')
@@ -228,7 +226,7 @@ class MixingHelpersTest(unittest.TestCase):
 
         # Print the MixingColorSpaceManager.
         self.assertEqual(str(mix),
-            ('config: $470958575eb3f906f985d31be8279e0d:$4dd1c89df8002b409e089089ce8f24e7, '
+            ('config: 779ee109137ff44de9afbf320685f4a2:6001c324468d497f99aa06d3014798d8, '
             'slider: [minEdge: 0, maxEdge: 1], mixingSpaces: [color_picking (log_1)], '
             'selectedMixingSpaceIdx: 0, selectedMixingEncodingIdx: 1, colorPicking'))
 
@@ -253,8 +251,8 @@ class MixingHelpersTest(unittest.TestCase):
         mix.setSelectedMixingSpaceIdx(0) # i.e. Rendering Space
         self.assertEqual(mix.getSelectedMixingSpaceIdx(), 0)
 
-        slider.setSliderMinEdge(0.0);
-        slider.setSliderMaxEdge(1.0);
+        slider.setSliderMinEdge(0.0)
+        slider.setSliderMaxEdge(1.0)
 
         self.assertTrue(test_percent_1000(    0, slider.getSliderMinEdge()))
         self.assertTrue(test_percent_1000(83386, slider.getSliderMaxEdge()))
